plot_Detection12 <- function(model, spname = NULL, min.yr = NULL, CI=95){
  
  
  # convert the CI into quantiles
  # first check that CI is sensible
  if((CI > 100) | (CI <= 0)) stop("Credible intervals must be between 0 and 100")
  CI2q <- function(CI) {
    q <- (1 - CI/100)/2
    return(c(q, 1-q))
  }
  q <- CI2q(CI)
  
  sims_list <- model$BUGSoutput$sims.list
  
  # the base: alpha.p is common to all models: 
  # it's the logit probability of detection on a single species list
  pDet1 <- sims_list$alpha.p
  # pDet1 is an array of dims equal to (niter, nyr)
  
  if("beta1" %in% names(sims_list)){
    # we ran the Julian Date option
    # So let's scale the detection probabilities to end June (day 180)
    pDet1 <- apply(pDet1, 2, function(x) 
      x + 180 * sims_list$beta1[,1] +  180^2 * sims_list$beta2[,1]
    )
  }
  
  # now calculate the equivalent values for lists of length 2 and 4 
  if("LL.p" %in% names(sims_list)){
    # the model was fitted with continuous list length
    pDet2 <- pDet1 + sims_list$LL.p * log(2)
    pDet4 <- pDet1 + sims_list$LL.p * log(4)
  } else if("dtype2.p" %in% names(sims_list)){
    # the model was fitted with categorical list length
    pDet2 <- pDet1 + sims_list$dtype2.p[,1]
    pDet4 <- pDet1 + sims_list$dtype3.p[,1]
  } 
  # there is also an option to ignore list length, 
  # in which case the probability of detection is assumed to be constant across surveys
  # i.e. if the survey was systematic
  
  pDet <- melt(list(pDet1, pDet2, pDet4))
  names(pDet) <- c("it", "year", "lgt_pDet", "ListLength")
  pDet$ListLength[pDet$ListLength==3] <- 4 # the "third" category is for a list of length 4
  
  pDet$pDet <- boot::inv.logit(pDet$lgt_pDet)
  
  #Plot detection for last time period
  gp2 <- ggplot(data = subset(pDet, year==12)) +
    geom_violin(aes(x=as.factor(ListLength), y=pDet), alpha=0.2) +
    ylab("Detection probability") +
    xlab("ListLength")
    ggtitle(spname) +
    scale_y_continuous(limits=c(0,1), breaks=seq(0,1,0.1)) +
    theme_classic(base_size = 12)
  
  
  gp2
  
}
